@@ -1,20 +1,26 @@
 # Data::Object::Prototype Instance Class
 package Data::Object::Prototype::Instance;
 
-use Moo ();
-use Moo::Role ();
+use 5.10.0;
 
-our $VERSION = '0.02'; # VERSION
+use strict;
+use warnings;
+
+require Moo;
+require Moo::Role;
+
+use Data::Object::Class;
+
+our $VERSION = '0.03'; # VERSION
 
 *package = sub {
     require Data::Object::Prototype::Package;
-    return Data::Object::Prototype::Package->new(
-        name => ref($_[0]) || $_[0]
-    )
+    return  Data::Object::Prototype::Package->new(name => ref($_[0]) || $_[0]);
 };
 
 my $c = 0;
 my $m = 0;
+
 sub DEMOLISH {
     my $self  = shift;
     my $class = ref($self) || $self;
@@ -29,10 +35,12 @@ sub DEMOLISH {
         no strict 'refs';
         my $table = "${class}::";
         my %symbols = %$table;
+
         for my $symbol (keys %symbols) {
             next if $symbol =~ /\A[^:]+::\z/;
             delete $symbols{$symbol};
         }
+
         my $file = join('/', split('::', $class)) . 'pm';
         delete $INC{$file};
     }
@@ -41,3 +49,4 @@ sub DEMOLISH {
 }
 
 1;
+
